package VMOMI::CannotMoveFaultToleranceVmMoveType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
